==> ehome-rcm-0.12.3.tgz: package/es/form-view/fields/Date/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';

var DateField =
/*#__PURE__*/
function (_ref) {
  _inherits(DateField, _ref);

  function DateField(props) {
    var _this;

    _classCallCheck(this, DateField);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DateField).call(this, props));
    _this.state = {};
    return _this;
  }

  _createClass(DateField, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue,
          _field$fieldExtra = field.fieldExtra,
          fieldExtra = _field$fieldExtra === void 0 ? '{}' : _field$fieldExtra;
      fieldValue = JSON.parse(fieldValue);
      fieldExtra = JSON.parse(fieldExtra);
      var _fieldValue = fieldValue,
          text = _fieldValue.text,
          _fieldValue$texts = _fieldValue.texts,
          texts = _fieldValue$texts === void 0 ? [] : _fieldValue$texts;
      var _fieldExtra = fieldExtra,
          mode = _fieldExtra.mode;
      var showText;
      var nullValue;

      if (mode === 'RANGE') {
        if (!texts.length) {
          showText = '无';
          nullValue = true;
        } else if (layoutType === 0) {
          showText = React.createElement("div", null, React.createElement("div", null, texts[0]), React.createElement("div", null, "~ ", texts[1]));
        } else {
          showText = "".concat(texts[0], " ~ ").concat(texts[1]);
        }
      } else {
        showText = text || '无';
        nullValue = !text;
      }

      var prefixCls = 'eh-field-view-date';
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && nullValue;
      return hidden ? null : React.createElement("div", {
        className: prefixCls
      }, React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value")
      }, showText));
    }
  }]);

  return DateField;
}(PureComponent || Component);

DateField.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
DateField.defaultProps = {
  field: {}
};
export default DateField;

==> ehome-rcm-0.15.2.tgz: package/es/form-view/fields/Date/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';

var DateField = /*#__PURE__*/function (_ref) {
  _inherits(DateField, _ref);

  var _super = _createSuper(DateField);

  function DateField(props) {
    var _this;

    _classCallCheck(this, DateField);

    _this = _super.call(this, props);
    _this.state = {};
    return _this;
  }

  _createClass(DateField, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue,
          _field$fieldExtra = field.fieldExtra,
          fieldExtra = _field$fieldExtra === void 0 ? '{}' : _field$fieldExtra;
      fieldValue = JSON.parse(fieldValue);
      fieldExtra = JSON.parse(fieldExtra);
      var _fieldValue = fieldValue,
          text = _fieldValue.text,
          _fieldValue$texts = _fieldValue.texts,
          texts = _fieldValue$texts === void 0 ? [] : _fieldValue$texts;
      var _fieldExtra = fieldExtra,
          mode = _fieldExtra.mode;
      var showText;
      var nullValue;

      if (mode === 'RANGE') {
        if (!texts.length) {
          showText = '无';
          nullValue = true;
        } else if (layoutType === 0) {
          showText = /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", null, texts[0]), /*#__PURE__*/React.createElement("div", null, "~ ", texts[1]));
        } else {
          showText = "".concat(texts[0], " ~ ").concat(texts[1]);
        }
      } else {
        showText = text || '无';
        nullValue = !text;
      }

      var prefixCls = 'eh-field-view-date';
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && nullValue;
      return hidden ? null : /*#__PURE__*/React.createElement("div", {
        className: prefixCls
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), /*#__PURE__*/React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value")
      }, showText));
    }
  }]);

  return DateField;
}(PureComponent || Component);

DateField.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
DateField.defaultProps = {
  field: {}
};
export default DateField;
